pub enum CursorAffinity {
Forward,
Backward,
}Expand description
Decides how the cursor should be placed around special areas of text.
Ex:
let j = // soft linewrap
1 + 2 + 3;where let j = has the issue that there’s two positions you might want your cursor to be:
let j = | or |1 + 2 + 3;
These are the same offset in the text, but it feels more natural to have it move in a certain
way.
If you’re at let j =| and you press the right-arrow key, then it uses your backwards
affinity to keep you on the line at let j = |.
If you’re at 1| + 2 + 3; and you press the left-arrow key, then it uses your forwards affinity
to keep you on the line at |1 + 2 + 3;.
For other special text, like inlay hints, this can also apply.
let j<: String> = ...where <: String> is our inlay hint, then
let |j<: String> = and you press the right-arrow key, then it uses your backwards affinity to
keep you on the same side of the hint, let j|<: String>.
let j<: String> |= and you press the right-arrow key, then it uses your forwards affinity to
keep you on the same side of the hint, let j<: String>| =.
Variants
Implementations
Sourceimpl CursorAffinity
impl CursorAffinity
pub fn invert(&self) -> CursorAffinity